#
# spec file for package ghc-githash
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name githash
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.7.0
Release:        lp160.1.2
Summary:        Compile git revision info into Haskell projects
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-th-compat-devel
BuildRequires:  ghc-th-compat-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-temporary-prof
BuildRequires:  ghc-unliftio-devel
BuildRequires:  ghc-unliftio-prof
%endif

%description
Compile git revision info into Haskell projects.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Jun 21 2023 Peter Simons <psimons@suse.com>
- Update githash to version 0.1.7.0.
  [#]# 0.1.7.0
  * Expose giFiles to users.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Oct 23 2022 Peter Simons <psimons@suse.com>
- Update githash to version 0.1.6.3.
  [#]# 0.1.6.3
  * Specify protocol.file.allow=always for latest git [#28](https://github.com/snoyberg/githash/pull/28)
* Mon Sep 20 2021 psimons@suse.com
- Update githash to version 0.1.6.2.
  [#]# 0.1.6.2
  * Fixed bugs; now this library's Template Haskell functions are much more
    likely on recompilation to detect Git update that doesn't affect workspace:
    e.g. `git switch -c <new_branch>` (equivalently
    `git checkout -b <new_branch>`) and `git commit --amend --only`.
    Implemented in [#23](https://github.com/snoyberg/githash/pull/23).
* Thu Jun 24 2021 psimons@suse.com
- Update githash to version 0.1.6.1.
  [#]# 0.1.6.1
  * [Support template-haskell 2.17](https://github.com/snoyberg/githash/pull/22)
* Wed Jun  9 2021 psimons@suse.com
- Update githash to version 0.1.6.0.
  [#]# 0.1.6.0
  * Always include patchlevel and hash in git-describe output
  * Don't let user's configured initial branch name break tests
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Oct 27 2020 psimons@suse.com
- Update githash to version 0.1.5.0.
  [#]# 0.1.5.0
  * Add git tag output via git-describe
* Tue Sep  1 2020 psimons@suse.com
- Update githash to version 0.1.4.0.
  [#]# 0.1.4.0
  * Add git-describe output
* Mon Dec 23 2019 psimons@suse.com
- Add githash at version 0.1.3.3.
